@@ -154,7 +154,7 @@ def metastable_from_msm(msm, n_hidden_states: int,
                         separate_symbols=None, regularize: bool = True):
     r""" Makes an initial guess for an :class:`HMM <deeptime.markov.hmm.HiddenMarkovModel>` with
     discrete output model from an already existing MSM over observable states. The procedure is described in
-    :cite:`hmm-init-msm-noe2013projected` and uses PCCA+ :cite:`hmm-init-msm-roblitz2013fuzzy` for
+    :footcite:`noe2013projected` and uses PCCA+ :footcite:`roblitz2013fuzzy` for
     coarse-graining the transition matrix and obtaining membership assignments.
 
     Parameters
@@ -185,21 +185,18 @@ def metastable_from_msm(msm, n_hidden_states: int,
 
     See Also
     --------
-    :class:`DiscreteOutputModel <deeptime.markov.hmm.DiscreteOutputModel>`
+    deeptime.markov.hmm.DiscreteOutputModel
         The type of output model this heuristic uses.
 
     :func:`metastable_from_data`
         Initial guess from data if no MSM is available yet.
 
-    :func:`init.gaussian.from_data <deeptime.markov.hmm.init.gaussian.from_data>`
+    :func:`deeptime.markov.hmm.init.gaussian.from_data`
         Initial guess with :class:`Gaussian output model <deeptime.markov.hmm.GaussianOutputModel>`.
 
     References
     ----------
-    .. bibliography:: /references.bib
-        :style: unsrt
-        :filter: docname in docnames
-        :keyprefix: hmm-init-msm-
+    .. footbibliography::
     """
     from deeptime.markov._transition_matrix import stationary_distribution
     from deeptime.markov._transition_matrix import estimate_P
@@ -280,9 +277,9 @@ def metastable_from_data(dtrajs, n_hidden_states, lagtime, stride=1, mode='large
     r"""Estimates an initial guess :class:`HMM <deeptime.markov.hmm.HiddenMarkovModel>` from given
     discrete trajectories.
 
-    Following the procedure described in :cite:`hmm-init-data-noe2013projected`: First
+    Following the procedure described in :footcite:`noe2013projected`: First
     a :class:`MSM <deeptime.markov.msm.MarkovStateModel>` is estimated, which is then subsequently
-    coarse-grained with PCCA+ :cite:`hmm-init-data-roblitz2013fuzzy`. After estimation of the MSM, this
+    coarse-grained with PCCA+ :footcite:`roblitz2013fuzzy`. After estimation of the MSM, this
     method calls :meth:`metastable_from_msm`.
 
     Parameters
@@ -354,29 +351,25 @@ def metastable_from_data(dtrajs, n_hidden_states, lagtime, stride=1, mode='large
 
     See Also
     --------
-    :class:`DiscreteOutputModel <deeptime.markov.hmm.DiscreteOutputModel>`
+    DiscreteOutputModel
         The type of output model this heuristic uses.
 
     :func:`metastable_from_msm`
         Initial guess from an already existing :class:`MSM <deeptime.markov.msm.MarkovStateModel>`.
 
-    :func:`init.gaussian.from_data <deeptime.markov.hmm.init.gaussian.from_data>`
+    :func:`deeptime.markov.hmm.init.gaussian.from_data`
         Initial guess with :class:`Gaussian output model <deeptime.markov.hmm.GaussianOutputModel>`.
 
 
     References
     ----------
-    .. bibliography:: /references.bib
-        :style: unsrt
-        :filter: docname in docnames
-        :keyprefix: hmm-init-data-
+    .. footbibliography::
     """
     if mode not in metastable_from_data.VALID_MODES \
             + [m + "-regularized" for m in metastable_from_data.VALID_MODES]:
         raise ValueError("mode can only be one of [{}]".format(", ".join(metastable_from_data.VALID_MODES)))
 
-    from deeptime.markov.util import compute_dtrajs_effective
-    from deeptime.markov import TransitionCountEstimator
+    from deeptime.markov import compute_dtrajs_effective, TransitionCountEstimator
 
     dtrajs = ensure_dtraj_list(dtrajs)
     dtrajs = compute_dtrajs_effective(dtrajs, lagtime=lagtime, n_states=n_hidden_states, stride=stride)
